#
# spec file for package gnome-characters
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-characters
Version:        47.0
Release:        1.3
Summary:        Character Map
License:        GPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Design/Apps/CharacterMap
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  intltool >= 0.50.1
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  xorg-x11-server-Xvfb
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gjs-1.0) >= 1.43.3
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.35.9
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.0
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangoft2)
# Ensure default sections are filled with content
Recommends:     google-noto-coloremoji-fonts
Requires:       /usr/bin/gjs-console

%description
A simple utility application to find and insert unusual characters.

%package -n gnome-shell-search-provider-gnome-characters
Summary:        GNOME Characters -- Search Provider for GNOME Shell
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Supplements:    (gnome-shell and %{name})
BuildArch:      noarch

%description -n gnome-shell-search-provider-gnome-characters
This package contains a search provider to enable GNOME Shell to get
search results from GNOME Characters.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D pangoft2=true \
	-D installed_tests=false \
	%{nil}
%meson_build

%install
%meson_install
%find_lang org.gnome.Characters %{name}.lang

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Characters.desktop
# test suite newly requires X display
export DISPLAY=:98
# setting and exporting LIBGL_ALWAYS_SOFTWARE=1 to get rid of
# issues when Mesa is trying to load 'zink' driver (messages are
# just warnings, but seem to be fatal for the tests here) (boo#1219095)
export LIBGL_ALWAYS_SOFTWARE=1
Xvfb :98 >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10
%meson_test || :

%files
%license COPYING
%{_bindir}/gnome-characters
%{_datadir}/metainfo/org.gnome.Characters.appdata.xml
%{_datadir}/org.gnome.Characters/
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/glib-2.0/schemas/org.gnome.Characters.gschema.xml
%{_datadir}/icons/hicolor/*
%{_datadir}/applications/org.gnome.Characters.desktop
%{_datadir}/dbus-1/services/org.gnome.Characters.service
%{_libdir}/org.gnome.Characters/

%files -n gnome-shell-search-provider-gnome-characters
%{_datadir}/gnome-shell/search-providers/org.gnome.Characters.search-provider.ini

%files lang -f %{name}.lang

%changelog
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + Update to Emoji 16.0.
  + Updated translations.
* Mon Aug 26 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.alpha:
  + Update to CLDR 45
  + Use adaptive dialogs
  + Updated translations.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Update to CLDR 44.
  + Update to Emoji 15.1.
  + Improve appdata for AppStream 1.0.
  + Updated translations.
* Fri Mar  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Ignore test suite failures: they pass locally (and in the
  upstream CI).
* Mon Oct  9 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add explicit /usr/bin/gjs-console requires:
  /usr/bin/gnome-characters is a symlink and is thus not inspected
  by RPM for its hashbang (boo#1216028).
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Updated translations.
* Tue Sep 12 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Re-enable test suite:
  + BuildRequire xorg-x11-server-Xvfb: the tests require a
    graphical environment.
  + Configure the tests to run using Xvfb.
* Fri Jul  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Update for Unicode 15.0.1
  + Add support for new Unicode CJK extensions
  + Bugs fixed:
  - Unable to search and display the character "䷿" U+4DFF
  - The "Latin Small Letter Long S" (ſ — U+017F) is missing from
    the application
  - Nonspacing marks should not be considered invisible
  - 44.rc: search provider crashes on shutdown
  + Updated translations.
* Fri Mar 31 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Replace noto-coloremoji-fonts  with google-noto-coloremoji-fonts
  Recommends, font package was renamed.
* Sun Mar 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Update for Unicode 15
  + Misc. string updates
  + Avoid downscaling search result icon
  + Use action-name properties
  + Updated translations.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Update for Unicode 15
  + Misc. string updates
  + Avoid downscaling search result icon
  + Use action-name properties
* Sat Dec 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Update to Unicode 15.
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Add support for composite emoji.
  + Use AdwAboutWindow for an adaptive about window.
  + Updated translations.
- Build sub-package gnome-shell-search-provider-gnome-characters as
  noarch.
* Sun Sep  4 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 43.rc:
  + Updated translations.
* Sun Aug  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Updated translations.
* Thu Jul 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Add support for composite emoji.
  + Use AdwAboutWindow for an adaptive about window.
  + Updated translations.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Port to GTK4 / libadwaita.
  + Fixes & improvements to the search provider.
  + Updated translations.
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Fix reflowing in size_allocate().
  + Updated translations.
* Mon Feb 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Fixed search provider issues
  + Search provider now displays the characters as well
  + Updated translations.
- Drop no longer needed BuildRequires after gtk4 port:
  + libunistring-devel
  + pkgconfig(gdk-3.0)
  + pkgconfig(glib-2.0)
  + pkgconfig(gobject-2.0)
- Replace gobject-introspection-devel with
  pkgconfig(gobject-introspection-1.0) BuildRequires.
- Add explicit pkgconfig(pangoft2) BuildRequires, meson checks for
  it, and we already pass pangoft2=true to meson.
- Add appstream-glib and desktop-file-utils, add check section and
  meson_test macro, as well as manually validate desktop file. Drop
  update-desktop-files BuildRequires and macro, no longer needed.
* Thu Feb 10 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + Ported to GTK4 and libadwaita
  + Gained support for the new dark style preference via libadwaita
- Change BuildRequires according to the GTK4 port:
  + Replace pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + Replace pkgconfig(libhandy-1) with pkgconfig(libadwaita-1)
- Drop mesonfix-061.patch: Fixed upstream.
* Thu Feb 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add mesonfix-061.patch: Fix build with meson 0.61 and newer.
- Update our Supplements to current standard.
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Bugs fixed: window: Show the close button on the sidebar.
  + Updated translations.
* Sun Mar 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Characters has received a visual upgrade, and is now able to be
    used across mobile and desktop form factors.
  + Updated translations.
- New build requirement: pkgconfig(libhandy-1).
* Thu Feb 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + searchProvider: Fix deprecation fixes.
  + Improves search entry and exit behaviour.
  + Fix deprecation warnings.
  + Fix single instance application mode.
  + Snap and flatpak fixes.
* Tue Apr  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + SearchProvider: Fix deprecation fixes.
  + Updated translations.
* Fri Mar 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Update the icon to follow the GNOME 3.32 guidelines.
  + Remove app menu following GNOME 3.32 guidelines.
  + Fix various javascript deprecation warnings.
  + Updated translations.
* Tue Oct  9 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Re-enable GNOME Shell search provider by default.
* Sat Aug 18 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + Port to modern JavaScript.
  + build: Drop autotools support.
  + Updated translations.
* Mon May  7 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + libgc: Fix crasher with some GCC configurations.
  + Updated translations.
- Switch to meson builds system: Add meson and new dependency
  libunistring-devel BuildRequires.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Character: Avoid critical warning after closing the dialog.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + build: Port to meson build system.
  + libgc: Perform full canonical decomposition for Hangul
    syllables.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Dec  7 2017 fcrozat@suse.com
- Add noto-coloremoji-fonts as a Recommends, otherwise application
  looks very ugly when no emoji fonts are installed.
* Wed Nov  1 2017 badshah400@gmail.com
- Update to version 3.26.2:
  - window: Fix error when searching on recently used page.
  - Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + characterList: Make search work again
  + Updated translations.
- Drop no longer needed post(un) macros:
  glib2_gsettings_schema_post(un) and icon_theme_cache_post(un),
  file triggers takes care of this now.
* Wed Sep  6 2017 luc14n0@linuxmail.org
- Update to version 3.25.92:
  + ui: Implement Emoji subcategories.
  + character: Add to Recent list when copied not viewed.
  + charatrerList: load more on resize.
  + Build fixes.
  + Updated translations.
* Tue Jul  4 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + characterList: Add NULL check for character name.
  + characterlist.ui: Improve the 'no result' strings.
  + searchProvider: add clipboardText to result meta.
  + categoryList: Make IBus detection robuster.
  + Updated translations.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + build: Fix appdata installation.
  + build: Don't run intltoolize in autogen.sh.
  + build: Regenerate uninames.h.
  + Add more options to XGETTEXT_OPTIONS in po/Makevars.
  + Updated translations.
* Fri Aug 26 2016 zaitor@opensuse.org
- Update to version 3.21.91.1:
  + Remove intltool markers from .appdata and .desktop.
  + Update tables for "See Also" list to Unicode 9.0.0.
  + Updated translations.
* Thu Aug 25 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Update Unicode standard to 9.0.0.
  + characterList: Support drag and drop of characters
    (bgo#764757).
  + Updated translations.
* Sun Apr 10 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Update AppData.
  + Fix regression in multi-keyword search with search provider
    (bgo#747061).
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Mon Mar 14 2016 zaitor@opensuse.org
- Update to version 3.19.92:
  + Add additional keywords to .desktop (bgo#762576).
  + Disable subtitle in the headerbar (bgo#763177).
  + Remove redundant horizontal padding in filter menu
    (bgo#763233).
  + Updated translations.
* Mon Feb 15 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Make "copy character" work again with newer GTK+.
  + Make search provider work again with the new internal search
    API.
  + Hide missing characters by default (bgo#744591).
  + Update appdata to 0.7+ format and add missing data.
  + The search provider now only shows prefix matches (bgo#757368).
  + Visual fixes for category list (bgo#761793).
  + Visual fixes for font list (bgo#748717).
  + Updated translations.
* Mon Dec 21 2015 damjanovic.ivo@gmail.com
- Update to version 3.19.3:
  + Add visual feedback for invisible characters (bgo#757815).
  + Rework search function to feed more results when the user
    scrolls the list to the bottom (bgo#757523).
  + Standardize app menu.
  + Updated translations.
* Sun Oct 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Disable search provider by default.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Update tables for "See Also" list to Unicode 8.0.0.
  + Updated translations.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Fix font filtering logic.
  + Close font filtering popover after selection.
  + Fix character name display for CJK ideographs.
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Fix bgo#753113: make fails without gperf.
  + Updated translations.
* Wed Jul 29 2015 zaitor@opensuse.org
- Update to version 3.17.4.1:
  + Fix bgo#752954: gnome-characters 3.17.4 no longer installs
    appdata.
  + Install all hicolor icons under $datadir/icons/hicolor.
  + Updated translations.
* Tue Jul 21 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Update Unicode standard to 8.0.0.
  + Bugs fixed: bgo#752607, bgo#743643, bgo#748717, bgo#748124,
    bgo#747398, bgo#747061.
  + Updated translations.
* Wed Jun 24 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata/ for openSUSE 42.
* Mon May 11 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix bgo#748124: build failure.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + bgo#747061: Search sometimes has poor results.
  + Updated translations.
* Sat Apr  4 2015 vuntz@opensuse.org
- Add %%post/%%postun scriptlets with
  %%glib2_gsettings_schema_post(un), %%icon_theme_cache_post(un) and
  "%%icon_theme_cache_post(un) gnome" (as the application installs
  icons in both hicolor and gnome icon themes).
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + bgo#745508: Two fixes to the search provider.
  + Fix non-BMP character display.
  + Make search keyword match against hex code point.
  + Add key navigation with cursor keys (without modifiers).
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91.1:
  + Restore the resizing behavior, which was broken in the last
    release.
- Changes from version 3.15.91:
  + bgo#744336: Add a unique application icon.
  + bgo#744855: Search provider.
  + Add more characters to "Pictures" section.
  + Add more characters to "See Also" list, by using Unicode
    character compositions.
* Mon Feb 16 2015 dimstar@opensuse.org
- Initial package, version 3.15.90.
